@@ -17,7 +17,7 @@ use Thread::Queue;
 use threads::shared;
 
 use FindBin;
-use lib "$FindBin::RealBin/../lib";
+use lib "$FindBin::RealBin/../lib/perl5";
 use Mashtree qw/logmsg @fastqExt @fastaExt createTreeFromPhylip/;
 use Mashtree::Db;
 use Bio::SeqIO;
@@ -40,8 +40,6 @@ sub main{
   mkdir($$settings{tempdir}) if(!-d $$settings{tempdir});
   $$settings{numcpus}||=1;
 
-  logmsg "WARNING this script is no longer maintained";
-
   logmsg "Temporary directory will be $$settings{tempdir}";
 
   die usage() if($$settings{help});
